/****************************************************************************
** Meta object code from reading C++ file 'extensionpluginmanager_p.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../../../dde-file-manager/src/plugins/common/dfmplugin-utils/extensionimpl/pluginsload/extensionpluginmanager_p.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'extensionpluginmanager_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_dfmplugin_utils__ExtensionPluginInitWorker_t {
    QByteArrayData data[9];
    char stringdata0[158];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_dfmplugin_utils__ExtensionPluginInitWorker_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_dfmplugin_utils__ExtensionPluginInitWorker_t qt_meta_stringdata_dfmplugin_utils__ExtensionPluginInitWorker = {
    {
QT_MOC_LITERAL(0, 0, 42), // "dfmplugin_utils::ExtensionPlu..."
QT_MOC_LITERAL(1, 43, 17), // "requestInitPlugin"
QT_MOC_LITERAL(2, 61, 0), // ""
QT_MOC_LITERAL(3, 62, 22), // "ExtPluginLoaderPointer"
QT_MOC_LITERAL(4, 85, 19), // "scanPluginsFinished"
QT_MOC_LITERAL(5, 105, 19), // "loadPluginsFinished"
QT_MOC_LITERAL(6, 125, 19), // "initPluginsFinished"
QT_MOC_LITERAL(7, 145, 6), // "doWork"
QT_MOC_LITERAL(8, 152, 5) // "paths"

    },
    "dfmplugin_utils::ExtensionPluginInitWorker\0"
    "requestInitPlugin\0\0ExtPluginLoaderPointer\0"
    "scanPluginsFinished\0loadPluginsFinished\0"
    "initPluginsFinished\0doWork\0paths"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_dfmplugin_utils__ExtensionPluginInitWorker[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       5,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       4,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   39,    2, 0x06 /* Public */,
       4,    0,   42,    2, 0x06 /* Public */,
       5,    0,   43,    2, 0x06 /* Public */,
       6,    0,   44,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       7,    1,   45,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, QMetaType::QStringList,    8,

       0        // eod
};

void dfmplugin_utils::ExtensionPluginInitWorker::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<ExtensionPluginInitWorker *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->requestInitPlugin((*reinterpret_cast< ExtPluginLoaderPointer(*)>(_a[1]))); break;
        case 1: _t->scanPluginsFinished(); break;
        case 2: _t->loadPluginsFinished(); break;
        case 3: _t->initPluginsFinished(); break;
        case 4: _t->doWork((*reinterpret_cast< const QStringList(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (ExtensionPluginInitWorker::*)(ExtPluginLoaderPointer );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ExtensionPluginInitWorker::requestInitPlugin)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (ExtensionPluginInitWorker::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ExtensionPluginInitWorker::scanPluginsFinished)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (ExtensionPluginInitWorker::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ExtensionPluginInitWorker::loadPluginsFinished)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (ExtensionPluginInitWorker::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ExtensionPluginInitWorker::initPluginsFinished)) {
                *result = 3;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject dfmplugin_utils::ExtensionPluginInitWorker::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_dfmplugin_utils__ExtensionPluginInitWorker.data,
    qt_meta_data_dfmplugin_utils__ExtensionPluginInitWorker,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *dfmplugin_utils::ExtensionPluginInitWorker::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dfmplugin_utils::ExtensionPluginInitWorker::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_dfmplugin_utils__ExtensionPluginInitWorker.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int dfmplugin_utils::ExtensionPluginInitWorker::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void dfmplugin_utils::ExtensionPluginInitWorker::requestInitPlugin(ExtPluginLoaderPointer _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void dfmplugin_utils::ExtensionPluginInitWorker::scanPluginsFinished()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void dfmplugin_utils::ExtensionPluginInitWorker::loadPluginsFinished()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void dfmplugin_utils::ExtensionPluginInitWorker::initPluginsFinished()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
struct qt_meta_stringdata_dfmplugin_utils__ExtensionPluginManagerPrivate_t {
    QByteArrayData data[4];
    char stringdata0[70];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_dfmplugin_utils__ExtensionPluginManagerPrivate_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_dfmplugin_utils__ExtensionPluginManagerPrivate_t qt_meta_stringdata_dfmplugin_utils__ExtensionPluginManagerPrivate = {
    {
QT_MOC_LITERAL(0, 0, 46), // "dfmplugin_utils::ExtensionPlu..."
QT_MOC_LITERAL(1, 47, 15), // "startInitialize"
QT_MOC_LITERAL(2, 63, 0), // ""
QT_MOC_LITERAL(3, 64, 5) // "paths"

    },
    "dfmplugin_utils::ExtensionPluginManagerPrivate\0"
    "startInitialize\0\0paths"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_dfmplugin_utils__ExtensionPluginManagerPrivate[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   19,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::QStringList,    3,

       0        // eod
};

void dfmplugin_utils::ExtensionPluginManagerPrivate::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<ExtensionPluginManagerPrivate *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->startInitialize((*reinterpret_cast< const QStringList(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (ExtensionPluginManagerPrivate::*)(const QStringList & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ExtensionPluginManagerPrivate::startInitialize)) {
                *result = 0;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject dfmplugin_utils::ExtensionPluginManagerPrivate::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_dfmplugin_utils__ExtensionPluginManagerPrivate.data,
    qt_meta_data_dfmplugin_utils__ExtensionPluginManagerPrivate,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *dfmplugin_utils::ExtensionPluginManagerPrivate::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dfmplugin_utils::ExtensionPluginManagerPrivate::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_dfmplugin_utils__ExtensionPluginManagerPrivate.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int dfmplugin_utils::ExtensionPluginManagerPrivate::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void dfmplugin_utils::ExtensionPluginManagerPrivate::startInitialize(const QStringList & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
