/****************************************************************************
** Meta object code from reading C++ file 'searchmanager.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../../../dde-file-manager/src/plugins/filemanager/dfmplugin-search/searchmanager/searchmanager.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'searchmanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_dfmplugin_search__SearchManager_t {
    QByteArrayData data[15];
    char stringdata0[158];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_dfmplugin_search__SearchManager_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_dfmplugin_search__SearchManager_t qt_meta_stringdata_dfmplugin_search__SearchManager = {
    {
QT_MOC_LITERAL(0, 0, 31), // "dfmplugin_search::SearchManager"
QT_MOC_LITERAL(1, 32, 7), // "matched"
QT_MOC_LITERAL(2, 40, 0), // ""
QT_MOC_LITERAL(3, 41, 6), // "taskId"
QT_MOC_LITERAL(4, 48, 15), // "searchCompleted"
QT_MOC_LITERAL(5, 64, 12), // "searchStoped"
QT_MOC_LITERAL(6, 77, 7), // "fileAdd"
QT_MOC_LITERAL(7, 85, 3), // "url"
QT_MOC_LITERAL(8, 89, 10), // "fileDelete"
QT_MOC_LITERAL(9, 100, 10), // "fileRename"
QT_MOC_LITERAL(10, 111, 6), // "oldUrl"
QT_MOC_LITERAL(11, 118, 6), // "newUrl"
QT_MOC_LITERAL(12, 125, 21), // "onDConfigValueChanged"
QT_MOC_LITERAL(13, 147, 6), // "config"
QT_MOC_LITERAL(14, 154, 3) // "key"

    },
    "dfmplugin_search::SearchManager\0matched\0"
    "\0taskId\0searchCompleted\0searchStoped\0"
    "fileAdd\0url\0fileDelete\0fileRename\0"
    "oldUrl\0newUrl\0onDConfigValueChanged\0"
    "config\0key"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_dfmplugin_search__SearchManager[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       7,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       6,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   49,    2, 0x06 /* Public */,
       4,    1,   52,    2, 0x06 /* Public */,
       5,    1,   55,    2, 0x06 /* Public */,
       6,    1,   58,    2, 0x06 /* Public */,
       8,    1,   61,    2, 0x06 /* Public */,
       9,    2,   64,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      12,    2,   69,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void, QMetaType::QUrl,    7,
    QMetaType::Void, QMetaType::QUrl,    7,
    QMetaType::Void, QMetaType::QUrl, QMetaType::QUrl,   10,   11,

 // slots: parameters
    QMetaType::Void, QMetaType::QString, QMetaType::QString,   13,   14,

       0        // eod
};

void dfmplugin_search::SearchManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<SearchManager *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->matched((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 1: _t->searchCompleted((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 2: _t->searchStoped((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 3: _t->fileAdd((*reinterpret_cast< const QUrl(*)>(_a[1]))); break;
        case 4: _t->fileDelete((*reinterpret_cast< const QUrl(*)>(_a[1]))); break;
        case 5: _t->fileRename((*reinterpret_cast< const QUrl(*)>(_a[1])),(*reinterpret_cast< const QUrl(*)>(_a[2]))); break;
        case 6: _t->onDConfigValueChanged((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (SearchManager::*)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&SearchManager::matched)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (SearchManager::*)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&SearchManager::searchCompleted)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (SearchManager::*)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&SearchManager::searchStoped)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (SearchManager::*)(const QUrl & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&SearchManager::fileAdd)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (SearchManager::*)(const QUrl & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&SearchManager::fileDelete)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (SearchManager::*)(const QUrl & , const QUrl & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&SearchManager::fileRename)) {
                *result = 5;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject dfmplugin_search::SearchManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_dfmplugin_search__SearchManager.data,
    qt_meta_data_dfmplugin_search__SearchManager,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *dfmplugin_search::SearchManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dfmplugin_search::SearchManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_dfmplugin_search__SearchManager.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int dfmplugin_search::SearchManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void dfmplugin_search::SearchManager::matched(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void dfmplugin_search::SearchManager::searchCompleted(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void dfmplugin_search::SearchManager::searchStoped(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void dfmplugin_search::SearchManager::fileAdd(const QUrl & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void dfmplugin_search::SearchManager::fileDelete(const QUrl & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void dfmplugin_search::SearchManager::fileRename(const QUrl & _t1, const QUrl & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
