/****************************************************************************
** Meta object code from reading C++ file 'mountcontroldbus.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../../dde-file-manager/src/services/mountcontrol/mountcontroldbus.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mountcontroldbus.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_MountControlDBus_t {
    QByteArrayData data[9];
    char stringdata0[115];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_MountControlDBus_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_MountControlDBus_t qt_meta_stringdata_MountControlDBus = {
    {
QT_MOC_LITERAL(0, 0, 16), // "MountControlDBus"
QT_MOC_LITERAL(1, 17, 15), // "D-Bus Interface"
QT_MOC_LITERAL(2, 33, 35), // "org.deepin.Filemanager.MountC..."
QT_MOC_LITERAL(3, 69, 5), // "Mount"
QT_MOC_LITERAL(4, 75, 0), // ""
QT_MOC_LITERAL(5, 76, 4), // "path"
QT_MOC_LITERAL(6, 81, 4), // "opts"
QT_MOC_LITERAL(7, 86, 7), // "Unmount"
QT_MOC_LITERAL(8, 94, 20) // "SupportedFileSystems"

    },
    "MountControlDBus\0D-Bus Interface\0"
    "org.deepin.Filemanager.MountControl\0"
    "Mount\0\0path\0opts\0Unmount\0SupportedFileSystems"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_MountControlDBus[] = {

 // content:
       8,       // revision
       0,       // classname
       1,   14, // classinfo
       3,   16, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // classinfo: key, value
       1,    2,

 // slots: name, argc, parameters, tag, flags
       3,    2,   31,    4, 0x4a /* Public | isScriptable */,
       7,    2,   36,    4, 0x4a /* Public | isScriptable */,
       8,    0,   41,    4, 0x4a /* Public | isScriptable */,

 // slots: parameters
    QMetaType::QVariantMap, QMetaType::QString, QMetaType::QVariantMap,    5,    6,
    QMetaType::QVariantMap, QMetaType::QString, QMetaType::QVariantMap,    5,    6,
    QMetaType::QStringList,

       0        // eod
};

void MountControlDBus::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<MountControlDBus *>(_o);
        (void)_t;
        switch (_id) {
        case 0: { QVariantMap _r = _t->Mount((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QVariantMap(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QVariantMap*>(_a[0]) = std::move(_r); }  break;
        case 1: { QVariantMap _r = _t->Unmount((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QVariantMap(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QVariantMap*>(_a[0]) = std::move(_r); }  break;
        case 2: { QStringList _r = _t->SupportedFileSystems();
            if (_a[0]) *reinterpret_cast< QStringList*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject MountControlDBus::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_MountControlDBus.data,
    qt_meta_data_MountControlDBus,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *MountControlDBus::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MountControlDBus::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_MountControlDBus.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QDBusContext"))
        return static_cast< QDBusContext*>(this);
    return QObject::qt_metacast(_clname);
}

int MountControlDBus::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 3;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
