/****************************************************************************
** Meta object code from reading C++ file 'dockitemdatamanager.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../../../dde-file-manager/src/external/dde-dock-plugins/disk-mount/device/dockitemdatamanager.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dockitemdatamanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_DockItemDataManager_t {
    QByteArrayData data[23];
    char stringdata0[305];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_DockItemDataManager_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_DockItemDataManager_t qt_meta_stringdata_DockItemDataManager = {
    {
QT_MOC_LITERAL(0, 0, 19), // "DockItemDataManager"
QT_MOC_LITERAL(1, 20, 22), // "requesetSetDockVisible"
QT_MOC_LITERAL(2, 43, 0), // ""
QT_MOC_LITERAL(3, 44, 7), // "visible"
QT_MOC_LITERAL(4, 52, 10), // "mountAdded"
QT_MOC_LITERAL(5, 63, 12), // "DockItemData"
QT_MOC_LITERAL(6, 76, 4), // "item"
QT_MOC_LITERAL(7, 81, 12), // "mountRemoved"
QT_MOC_LITERAL(8, 94, 2), // "id"
QT_MOC_LITERAL(9, 97, 12), // "usageUpdated"
QT_MOC_LITERAL(10, 110, 4), // "used"
QT_MOC_LITERAL(11, 115, 14), // "onBlockMounted"
QT_MOC_LITERAL(12, 130, 16), // "onBlockUnmounted"
QT_MOC_LITERAL(13, 147, 22), // "onBlockPropertyChanged"
QT_MOC_LITERAL(14, 170, 8), // "property"
QT_MOC_LITERAL(15, 179, 12), // "QDBusVariant"
QT_MOC_LITERAL(16, 192, 5), // "value"
QT_MOC_LITERAL(17, 198, 17), // "onProtocolMounted"
QT_MOC_LITERAL(18, 216, 19), // "onProtocolUnmounted"
QT_MOC_LITERAL(19, 236, 16), // "sendNotification"
QT_MOC_LITERAL(20, 253, 9), // "operation"
QT_MOC_LITERAL(21, 263, 19), // "onServiceRegistered"
QT_MOC_LITERAL(22, 283, 21) // "onServiceUnregistered"

    },
    "DockItemDataManager\0requesetSetDockVisible\0"
    "\0visible\0mountAdded\0DockItemData\0item\0"
    "mountRemoved\0id\0usageUpdated\0used\0"
    "onBlockMounted\0onBlockUnmounted\0"
    "onBlockPropertyChanged\0property\0"
    "QDBusVariant\0value\0onProtocolMounted\0"
    "onProtocolUnmounted\0sendNotification\0"
    "operation\0onServiceRegistered\0"
    "onServiceUnregistered"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_DockItemDataManager[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      12,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       4,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   74,    2, 0x06 /* Public */,
       4,    1,   77,    2, 0x06 /* Public */,
       7,    1,   80,    2, 0x06 /* Public */,
       9,    2,   83,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      11,    1,   88,    2, 0x08 /* Private */,
      12,    1,   91,    2, 0x08 /* Private */,
      13,    3,   94,    2, 0x08 /* Private */,
      17,    1,  101,    2, 0x08 /* Private */,
      18,    1,  104,    2, 0x08 /* Private */,
      19,    2,  107,    2, 0x08 /* Private */,
      21,    0,  112,    2, 0x08 /* Private */,
      22,    0,  113,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void, 0x80000000 | 5,    6,
    QMetaType::Void, QMetaType::QString,    8,
    QMetaType::Void, QMetaType::QString, QMetaType::ULongLong,    8,   10,

 // slots: parameters
    QMetaType::Void, QMetaType::QString,    8,
    QMetaType::Void, QMetaType::QString,    8,
    QMetaType::Void, QMetaType::QString, QMetaType::QString, 0x80000000 | 15,    8,   14,   16,
    QMetaType::Void, QMetaType::QString,    8,
    QMetaType::Void, QMetaType::QString,    8,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,    8,   20,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void DockItemDataManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<DockItemDataManager *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->requesetSetDockVisible((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 1: _t->mountAdded((*reinterpret_cast< const DockItemData(*)>(_a[1]))); break;
        case 2: _t->mountRemoved((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 3: _t->usageUpdated((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< quint64(*)>(_a[2]))); break;
        case 4: _t->onBlockMounted((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 5: _t->onBlockUnmounted((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 6: _t->onBlockPropertyChanged((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QDBusVariant(*)>(_a[3]))); break;
        case 7: _t->onProtocolMounted((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 8: _t->onProtocolUnmounted((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 9: _t->sendNotification((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 10: _t->onServiceRegistered(); break;
        case 11: _t->onServiceUnregistered(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< DockItemData >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (DockItemDataManager::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DockItemDataManager::requesetSetDockVisible)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (DockItemDataManager::*)(const DockItemData & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DockItemDataManager::mountAdded)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (DockItemDataManager::*)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DockItemDataManager::mountRemoved)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (DockItemDataManager::*)(const QString & , quint64 );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DockItemDataManager::usageUpdated)) {
                *result = 3;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject DockItemDataManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_DockItemDataManager.data,
    qt_meta_data_DockItemDataManager,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *DockItemDataManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DockItemDataManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_DockItemDataManager.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int DockItemDataManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void DockItemDataManager::requesetSetDockVisible(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void DockItemDataManager::mountAdded(const DockItemData & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void DockItemDataManager::mountRemoved(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void DockItemDataManager::usageUpdated(const QString & _t1, quint64 _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
