/****************************************************************************
** Meta object code from reading C++ file 'burn.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../../../dde-file-manager/src/plugins/common/dfmplugin-burn/burn.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/qplugin.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'burn.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_dfmplugin_burn__Burn_t {
    QByteArrayData data[14];
    char stringdata0[156];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_dfmplugin_burn__Burn_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_dfmplugin_burn__Burn_t qt_meta_stringdata_dfmplugin_burn__Burn = {
    {
QT_MOC_LITERAL(0, 0, 20), // "dfmplugin_burn::Burn"
QT_MOC_LITERAL(1, 21, 9), // "bindScene"
QT_MOC_LITERAL(2, 31, 0), // ""
QT_MOC_LITERAL(3, 32, 11), // "parentScene"
QT_MOC_LITERAL(4, 44, 16), // "bindSceneOnAdded"
QT_MOC_LITERAL(5, 61, 8), // "newScene"
QT_MOC_LITERAL(6, 70, 10), // "bindEvents"
QT_MOC_LITERAL(7, 81, 20), // "changeUrlEventFilter"
QT_MOC_LITERAL(8, 102, 8), // "windowId"
QT_MOC_LITERAL(9, 111, 3), // "url"
QT_MOC_LITERAL(10, 115, 24), // "onPersistenceDataChanged"
QT_MOC_LITERAL(11, 140, 5), // "group"
QT_MOC_LITERAL(12, 146, 3), // "key"
QT_MOC_LITERAL(13, 150, 5) // "value"

    },
    "dfmplugin_burn::Burn\0bindScene\0\0"
    "parentScene\0bindSceneOnAdded\0newScene\0"
    "bindEvents\0changeUrlEventFilter\0"
    "windowId\0url\0onPersistenceDataChanged\0"
    "group\0key\0value"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_dfmplugin_burn__Burn[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       5,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   39,    2, 0x08 /* Private */,
       4,    1,   42,    2, 0x08 /* Private */,
       6,    0,   45,    2, 0x08 /* Private */,
       7,    2,   46,    2, 0x08 /* Private */,
      10,    3,   51,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void, QMetaType::QString,    5,
    QMetaType::Void,
    QMetaType::Bool, QMetaType::ULongLong, QMetaType::QUrl,    8,    9,
    QMetaType::Void, QMetaType::QString, QMetaType::QString, QMetaType::QVariant,   11,   12,   13,

       0        // eod
};

void dfmplugin_burn::Burn::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<Burn *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->bindScene((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 1: _t->bindSceneOnAdded((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 2: _t->bindEvents(); break;
        case 3: { bool _r = _t->changeUrlEventFilter((*reinterpret_cast< quint64(*)>(_a[1])),(*reinterpret_cast< const QUrl(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 4: _t->onPersistenceDataChanged((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QVariant(*)>(_a[3]))); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject dfmplugin_burn::Burn::staticMetaObject = { {
    QMetaObject::SuperData::link<dpf::Plugin::staticMetaObject>(),
    qt_meta_stringdata_dfmplugin_burn__Burn.data,
    qt_meta_data_dfmplugin_burn__Burn,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *dfmplugin_burn::Burn::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dfmplugin_burn::Burn::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_dfmplugin_burn__Burn.stringdata0))
        return static_cast<void*>(this);
    return dpf::Plugin::qt_metacast(_clname);
}

int dfmplugin_burn::Burn::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = dpf::Plugin::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 5;
    }
    return _id;
}

QT_PLUGIN_METADATA_SECTION
static constexpr unsigned char qt_pluginMetaData[] = {
    'Q', 'T', 'M', 'E', 'T', 'A', 'D', 'A', 'T', 'A', ' ', '!',
    // metadata version, Qt version, architectural requirements
    0, QT_VERSION_MAJOR, QT_VERSION_MINOR, qPluginArchRequirements(),
    0xbf, 
    // "IID"
    0x02,  0x78,  0x18,  'o',  'r',  'g',  '.',  'd', 
    'e',  'e',  'p',  'i',  'n',  '.',  'p',  'l', 
    'u',  'g',  'i',  'n',  '.',  'c',  'o',  'm', 
    'm',  'o',  'n', 
    // "className"
    0x03,  0x64,  'B',  'u',  'r',  'n', 
    // "MetaData"
    0x04,  0xaa,  0x68,  'C',  'a',  't',  'e',  'g', 
    'o',  'r',  'y',  0x60,  0x6d,  'C',  'o',  'm', 
    'p',  'a',  't',  'V',  'e',  'r',  's',  'i', 
    'o',  'n',  0x65,  '1',  '.',  '0',  '.',  '0', 
    0x69,  'C',  'o',  'p',  'y',  'r',  'i',  'g', 
    'h',  't',  0x78,  0x3a,  'C',  'o',  'p',  'y', 
    'r',  'i',  'g',  'h',  't',  ' ',  '(',  'C', 
    ')',  ' ',  '2',  '0',  '2',  '2',  ' ',  'U', 
    'n',  'i',  'o',  'n',  't',  'e',  'c',  'h', 
    ' ',  'S',  'o',  'f',  't',  'w',  'a',  'r', 
    'e',  ' ',  'T',  'e',  'c',  'h',  'n',  'o', 
    'l',  'o',  'g',  'y',  ' ',  'C',  'o',  '.', 
    ',',  ' ',  'L',  't',  'd',  '.',  0x67,  'D', 
    'e',  'p',  'e',  'n',  'd',  's',  0x80,  0x6b, 
    'D',  'e',  's',  'c',  'r',  'i',  'p',  't', 
    'i',  'o',  'n',  0x78,  0x32,  'T',  'h',  'e', 
    ' ',  'c',  'o',  'm',  'm',  'o',  'n',  ' ', 
    'p',  'l',  'u',  'g',  'i',  'n',  ' ',  'f', 
    'o',  'r',  ' ',  't',  'h',  'e',  ' ',  'f', 
    'i',  'l',  'e',  'm',  'a',  'n',  'a',  'g', 
    'e',  'r',  ' ',  'a',  'n',  'd',  ' ',  'd', 
    'e',  's',  'k',  't',  'o',  'p',  '.',  0x67, 
    'L',  'i',  'c',  'e',  'n',  's',  'e',  0x80, 
    0x64,  'N',  'a',  'm',  'e',  0x6e,  'd',  'f', 
    'm',  'p',  'l',  'u',  'g',  'i',  'n',  '-', 
    'b',  'u',  'r',  'n',  0x67,  'U',  'r',  'l', 
    'L',  'i',  'n',  'k',  0x78,  0x19,  'h',  't', 
    't',  'p',  's',  ':',  '/',  '/',  'w',  'w', 
    'w',  '.',  'u',  'n',  'i',  'o',  'n',  't', 
    'e',  'c',  'h',  '.',  'c',  'o',  'm',  0x66, 
    'V',  'e',  'n',  'd',  'o',  'r',  0x78,  0x2b, 
    'T',  'h',  'e',  ' ',  'U',  'n',  'i',  'o', 
    'n',  't',  'e',  'c',  'h',  ' ',  'S',  'o', 
    'f',  't',  'w',  'a',  'r',  'e',  ' ',  'T', 
    'e',  'c',  'h',  'n',  'o',  'l',  'o',  'g', 
    'y',  ' ',  'C',  'o',  '.',  ',',  ' ',  'L', 
    't',  'd',  '.',  0x67,  'V',  'e',  'r',  's', 
    'i',  'o',  'n',  0x65,  '1',  '.',  '0',  '.', 
    '0', 
    0xff, 
};
using namespace dfmplugin_burn;
QT_MOC_EXPORT_PLUGIN(dfmplugin_burn::Burn, Burn)

QT_WARNING_POP
QT_END_MOC_NAMESPACE
