/****************************************************************************
** Meta object code from reading C++ file 'smbbrowsereventreceiver.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../../../dde-file-manager/src/plugins/filemanager/dfmplugin-smbbrowser/events/smbbrowsereventreceiver.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'smbbrowsereventreceiver.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_dfmplugin_smbbrowser__SmbBrowserEventReceiver_t {
    QByteArrayData data[18];
    char stringdata0[219];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_dfmplugin_smbbrowser__SmbBrowserEventReceiver_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_dfmplugin_smbbrowser__SmbBrowserEventReceiver_t qt_meta_stringdata_dfmplugin_smbbrowser__SmbBrowserEventReceiver = {
    {
QT_MOC_LITERAL(0, 0, 45), // "dfmplugin_smbbrowser::SmbBrow..."
QT_MOC_LITERAL(1, 46, 14), // "detailViewIcon"
QT_MOC_LITERAL(2, 61, 0), // ""
QT_MOC_LITERAL(3, 62, 3), // "url"
QT_MOC_LITERAL(4, 66, 8), // "QString*"
QT_MOC_LITERAL(5, 75, 8), // "iconName"
QT_MOC_LITERAL(6, 84, 12), // "cancelDelete"
QT_MOC_LITERAL(7, 97, 11), // "QList<QUrl>"
QT_MOC_LITERAL(8, 109, 4), // "urls"
QT_MOC_LITERAL(9, 114, 7), // "rootUrl"
QT_MOC_LITERAL(10, 122, 17), // "cancelMoveToTrash"
QT_MOC_LITERAL(11, 140, 14), // "hookSetTabName"
QT_MOC_LITERAL(12, 155, 7), // "tabName"
QT_MOC_LITERAL(13, 163, 22), // "hookTitleBarAddrHandle"
QT_MOC_LITERAL(14, 186, 5), // "QUrl*"
QT_MOC_LITERAL(15, 192, 18), // "hookAllowRepeatUrl"
QT_MOC_LITERAL(16, 211, 3), // "cur"
QT_MOC_LITERAL(17, 215, 3) // "pre"

    },
    "dfmplugin_smbbrowser::SmbBrowserEventReceiver\0"
    "detailViewIcon\0\0url\0QString*\0iconName\0"
    "cancelDelete\0QList<QUrl>\0urls\0rootUrl\0"
    "cancelMoveToTrash\0hookSetTabName\0"
    "tabName\0hookTitleBarAddrHandle\0QUrl*\0"
    "hookAllowRepeatUrl\0cur\0pre"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_dfmplugin_smbbrowser__SmbBrowserEventReceiver[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       6,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    2,   44,    2, 0x0a /* Public */,
       6,    3,   49,    2, 0x0a /* Public */,
      10,    3,   56,    2, 0x0a /* Public */,
      11,    2,   63,    2, 0x0a /* Public */,
      13,    1,   68,    2, 0x0a /* Public */,
      15,    2,   71,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Bool, QMetaType::QUrl, 0x80000000 | 4,    3,    5,
    QMetaType::Bool, QMetaType::ULongLong, 0x80000000 | 7, QMetaType::QUrl,    2,    8,    9,
    QMetaType::Bool, QMetaType::ULongLong, 0x80000000 | 7, QMetaType::QUrl,    2,    2,    9,
    QMetaType::Bool, QMetaType::QUrl, 0x80000000 | 4,    3,   12,
    QMetaType::Bool, 0x80000000 | 14,    3,
    QMetaType::Bool, QMetaType::QUrl, QMetaType::QUrl,   16,   17,

       0        // eod
};

void dfmplugin_smbbrowser::SmbBrowserEventReceiver::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<SmbBrowserEventReceiver *>(_o);
        (void)_t;
        switch (_id) {
        case 0: { bool _r = _t->detailViewIcon((*reinterpret_cast< const QUrl(*)>(_a[1])),(*reinterpret_cast< QString*(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 1: { bool _r = _t->cancelDelete((*reinterpret_cast< quint64(*)>(_a[1])),(*reinterpret_cast< const QList<QUrl>(*)>(_a[2])),(*reinterpret_cast< const QUrl(*)>(_a[3])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 2: { bool _r = _t->cancelMoveToTrash((*reinterpret_cast< quint64(*)>(_a[1])),(*reinterpret_cast< const QList<QUrl>(*)>(_a[2])),(*reinterpret_cast< const QUrl(*)>(_a[3])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 3: { bool _r = _t->hookSetTabName((*reinterpret_cast< const QUrl(*)>(_a[1])),(*reinterpret_cast< QString*(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 4: { bool _r = _t->hookTitleBarAddrHandle((*reinterpret_cast< QUrl*(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 5: { bool _r = _t->hookAllowRepeatUrl((*reinterpret_cast< const QUrl(*)>(_a[1])),(*reinterpret_cast< const QUrl(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<QUrl> >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<QUrl> >(); break;
            }
            break;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject dfmplugin_smbbrowser::SmbBrowserEventReceiver::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_dfmplugin_smbbrowser__SmbBrowserEventReceiver.data,
    qt_meta_data_dfmplugin_smbbrowser__SmbBrowserEventReceiver,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *dfmplugin_smbbrowser::SmbBrowserEventReceiver::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dfmplugin_smbbrowser::SmbBrowserEventReceiver::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_dfmplugin_smbbrowser__SmbBrowserEventReceiver.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int dfmplugin_smbbrowser::SmbBrowserEventReceiver::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
