/****************************************************************************
** Meta object code from reading C++ file 'crumbbar.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../../../../dde-file-manager/src/plugins/filemanager/core/dfmplugin-titlebar/views/crumbbar.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'crumbbar.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_dfmplugin_titlebar__CrumbBar_t {
    QByteArrayData data[14];
    char stringdata0[178];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_dfmplugin_titlebar__CrumbBar_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_dfmplugin_titlebar__CrumbBar_t qt_meta_stringdata_dfmplugin_titlebar__CrumbBar = {
    {
QT_MOC_LITERAL(0, 0, 28), // "dfmplugin_titlebar::CrumbBar"
QT_MOC_LITERAL(1, 29, 18), // "showAddressBarText"
QT_MOC_LITERAL(2, 48, 0), // ""
QT_MOC_LITERAL(3, 49, 4), // "text"
QT_MOC_LITERAL(4, 54, 14), // "hideAddressBar"
QT_MOC_LITERAL(5, 69, 2), // "cd"
QT_MOC_LITERAL(6, 72, 11), // "selectedUrl"
QT_MOC_LITERAL(7, 84, 3), // "url"
QT_MOC_LITERAL(8, 88, 7), // "editUrl"
QT_MOC_LITERAL(9, 96, 19), // "onCustomContextMenu"
QT_MOC_LITERAL(10, 116, 5), // "point"
QT_MOC_LITERAL(11, 122, 12), // "onUrlChanged"
QT_MOC_LITERAL(12, 135, 16), // "onKeepAddressBar"
QT_MOC_LITERAL(13, 152, 25) // "onHideAddrAndUpdateCrumbs"

    },
    "dfmplugin_titlebar::CrumbBar\0"
    "showAddressBarText\0\0text\0hideAddressBar\0"
    "cd\0selectedUrl\0url\0editUrl\0"
    "onCustomContextMenu\0point\0onUrlChanged\0"
    "onKeepAddressBar\0onHideAddrAndUpdateCrumbs"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_dfmplugin_titlebar__CrumbBar[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       8,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       4,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   54,    2, 0x06 /* Public */,
       4,    1,   57,    2, 0x06 /* Public */,
       6,    1,   60,    2, 0x06 /* Public */,
       8,    1,   63,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       9,    1,   66,    2, 0x0a /* Public */,
      11,    1,   69,    2, 0x0a /* Public */,
      12,    1,   72,    2, 0x0a /* Public */,
      13,    1,   75,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void, QMetaType::Bool,    5,
    QMetaType::Void, QMetaType::QUrl,    7,
    QMetaType::Void, QMetaType::QUrl,    7,

 // slots: parameters
    QMetaType::Void, QMetaType::QPoint,   10,
    QMetaType::Void, QMetaType::QUrl,    7,
    QMetaType::Void, QMetaType::QUrl,    7,
    QMetaType::Void, QMetaType::QUrl,    7,

       0        // eod
};

void dfmplugin_titlebar::CrumbBar::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<CrumbBar *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->showAddressBarText((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 1: _t->hideAddressBar((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 2: _t->selectedUrl((*reinterpret_cast< const QUrl(*)>(_a[1]))); break;
        case 3: _t->editUrl((*reinterpret_cast< const QUrl(*)>(_a[1]))); break;
        case 4: _t->onCustomContextMenu((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
        case 5: _t->onUrlChanged((*reinterpret_cast< const QUrl(*)>(_a[1]))); break;
        case 6: _t->onKeepAddressBar((*reinterpret_cast< const QUrl(*)>(_a[1]))); break;
        case 7: _t->onHideAddrAndUpdateCrumbs((*reinterpret_cast< const QUrl(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (CrumbBar::*)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&CrumbBar::showAddressBarText)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (CrumbBar::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&CrumbBar::hideAddressBar)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (CrumbBar::*)(const QUrl & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&CrumbBar::selectedUrl)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (CrumbBar::*)(const QUrl & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&CrumbBar::editUrl)) {
                *result = 3;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject dfmplugin_titlebar::CrumbBar::staticMetaObject = { {
    QMetaObject::SuperData::link<QFrame::staticMetaObject>(),
    qt_meta_stringdata_dfmplugin_titlebar__CrumbBar.data,
    qt_meta_data_dfmplugin_titlebar__CrumbBar,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *dfmplugin_titlebar::CrumbBar::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dfmplugin_titlebar::CrumbBar::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_dfmplugin_titlebar__CrumbBar.stringdata0))
        return static_cast<void*>(this);
    return QFrame::qt_metacast(_clname);
}

int dfmplugin_titlebar::CrumbBar::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QFrame::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void dfmplugin_titlebar::CrumbBar::showAddressBarText(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void dfmplugin_titlebar::CrumbBar::hideAddressBar(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void dfmplugin_titlebar::CrumbBar::selectedUrl(const QUrl & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void dfmplugin_titlebar::CrumbBar::editUrl(const QUrl & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
