/****************************************************************************
** Meta object code from reading C++ file 'itemeditor.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../../../dde-file-manager/src/plugins/desktop/ddplugin-organizer/delegate/itemeditor.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'itemeditor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_ddplugin_organizer__RenameEdit_t {
    QByteArrayData data[4];
    char stringdata0[42];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ddplugin_organizer__RenameEdit_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ddplugin_organizer__RenameEdit_t qt_meta_stringdata_ddplugin_organizer__RenameEdit = {
    {
QT_MOC_LITERAL(0, 0, 30), // "ddplugin_organizer::RenameEdit"
QT_MOC_LITERAL(1, 31, 4), // "undo"
QT_MOC_LITERAL(2, 36, 0), // ""
QT_MOC_LITERAL(3, 37, 4) // "redo"

    },
    "ddplugin_organizer::RenameEdit\0undo\0"
    "\0redo"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ddplugin_organizer__RenameEdit[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       2,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   24,    2, 0x0a /* Public */,
       3,    0,   25,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void ddplugin_organizer::RenameEdit::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<RenameEdit *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->undo(); break;
        case 1: _t->redo(); break;
        default: ;
        }
    }
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject ddplugin_organizer::RenameEdit::staticMetaObject = { {
    QMetaObject::SuperData::link<Dtk::Widget::DTextEdit::staticMetaObject>(),
    qt_meta_stringdata_ddplugin_organizer__RenameEdit.data,
    qt_meta_data_ddplugin_organizer__RenameEdit,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *ddplugin_organizer::RenameEdit::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ddplugin_organizer::RenameEdit::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_ddplugin_organizer__RenameEdit.stringdata0))
        return static_cast<void*>(this);
    return Dtk::Widget::DTextEdit::qt_metacast(_clname);
}

int ddplugin_organizer::RenameEdit::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Dtk::Widget::DTextEdit::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 2;
    }
    return _id;
}
struct qt_meta_stringdata_ddplugin_organizer__ItemEditor_t {
    QByteArrayData data[8];
    char stringdata0[104];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ddplugin_organizer__ItemEditor_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ddplugin_organizer__ItemEditor_t qt_meta_stringdata_ddplugin_organizer__ItemEditor = {
    {
QT_MOC_LITERAL(0, 0, 30), // "ddplugin_organizer::ItemEditor"
QT_MOC_LITERAL(1, 31, 13), // "inputFocusOut"
QT_MOC_LITERAL(2, 45, 0), // ""
QT_MOC_LITERAL(3, 46, 14), // "updateGeometry"
QT_MOC_LITERAL(4, 61, 16), // "showAlertMessage"
QT_MOC_LITERAL(5, 78, 4), // "text"
QT_MOC_LITERAL(6, 83, 8), // "duration"
QT_MOC_LITERAL(7, 92, 11) // "textChanged"

    },
    "ddplugin_organizer::ItemEditor\0"
    "inputFocusOut\0\0updateGeometry\0"
    "showAlertMessage\0text\0duration\0"
    "textChanged"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ddplugin_organizer__ItemEditor[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       5,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   39,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       3,    0,   40,    2, 0x0a /* Public */,
       4,    2,   41,    2, 0x0a /* Public */,
       4,    1,   46,    2, 0x2a /* Public | MethodCloned */,
       7,    0,   49,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString, QMetaType::Int,    5,    6,
    QMetaType::Void, QMetaType::QString,    5,
    QMetaType::Void,

       0        // eod
};

void ddplugin_organizer::ItemEditor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<ItemEditor *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->inputFocusOut(); break;
        case 1: _t->updateGeometry(); break;
        case 2: _t->showAlertMessage((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 3: _t->showAlertMessage((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 4: _t->textChanged(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (ItemEditor::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ItemEditor::inputFocusOut)) {
                *result = 0;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject ddplugin_organizer::ItemEditor::staticMetaObject = { {
    QMetaObject::SuperData::link<QFrame::staticMetaObject>(),
    qt_meta_stringdata_ddplugin_organizer__ItemEditor.data,
    qt_meta_data_ddplugin_organizer__ItemEditor,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *ddplugin_organizer::ItemEditor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ddplugin_organizer::ItemEditor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_ddplugin_organizer__ItemEditor.stringdata0))
        return static_cast<void*>(this);
    return QFrame::qt_metacast(_clname);
}

int ddplugin_organizer::ItemEditor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QFrame::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void ddplugin_organizer::ItemEditor::inputFocusOut()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
