/****************************************************************************
** Meta object code from reading C++ file 'workspacehelper.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../../../../dde-file-manager/src/plugins/filemanager/core/dfmplugin-workspace/utils/workspacehelper.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'workspacehelper.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_dfmplugin_workspace__WorkspaceHelper_t {
    QByteArrayData data[13];
    char stringdata0[181];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_dfmplugin_workspace__WorkspaceHelper_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_dfmplugin_workspace__WorkspaceHelper_t qt_meta_stringdata_dfmplugin_workspace__WorkspaceHelper = {
    {
QT_MOC_LITERAL(0, 0, 36), // "dfmplugin_workspace::Workspac..."
QT_MOC_LITERAL(1, 37, 10), // "openNewTab"
QT_MOC_LITERAL(2, 48, 0), // ""
QT_MOC_LITERAL(3, 49, 8), // "windowId"
QT_MOC_LITERAL(4, 58, 3), // "url"
QT_MOC_LITERAL(5, 62, 18), // "requestSelectFiles"
QT_MOC_LITERAL(6, 81, 11), // "QList<QUrl>"
QT_MOC_LITERAL(7, 93, 7), // "urlList"
QT_MOC_LITERAL(8, 101, 17), // "trashStateChanged"
QT_MOC_LITERAL(9, 119, 30), // "installWorkspaceWidgetToWindow"
QT_MOC_LITERAL(10, 150, 8), // "windowID"
QT_MOC_LITERAL(11, 159, 16), // "handleRefreshDir"
QT_MOC_LITERAL(12, 176, 4) // "urls"

    },
    "dfmplugin_workspace::WorkspaceHelper\0"
    "openNewTab\0\0windowId\0url\0requestSelectFiles\0"
    "QList<QUrl>\0urlList\0trashStateChanged\0"
    "installWorkspaceWidgetToWindow\0windowID\0"
    "handleRefreshDir\0urls"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_dfmplugin_workspace__WorkspaceHelper[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       5,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       3,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    2,   39,    2, 0x06 /* Public */,
       5,    1,   44,    2, 0x06 /* Public */,
       8,    0,   47,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       9,    1,   48,    2, 0x0a /* Public */,
      11,    1,   51,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::ULongLong, QMetaType::QUrl,    3,    4,
    QMetaType::Void, 0x80000000 | 6,    7,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, QMetaType::ULongLong,   10,
    QMetaType::Void, 0x80000000 | 6,   12,

       0        // eod
};

void dfmplugin_workspace::WorkspaceHelper::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<WorkspaceHelper *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->openNewTab((*reinterpret_cast< quint64(*)>(_a[1])),(*reinterpret_cast< const QUrl(*)>(_a[2]))); break;
        case 1: _t->requestSelectFiles((*reinterpret_cast< const QList<QUrl>(*)>(_a[1]))); break;
        case 2: _t->trashStateChanged(); break;
        case 3: _t->installWorkspaceWidgetToWindow((*reinterpret_cast< const quint64(*)>(_a[1]))); break;
        case 4: _t->handleRefreshDir((*reinterpret_cast< const QList<QUrl>(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<QUrl> >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<QUrl> >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (WorkspaceHelper::*)(quint64 , const QUrl & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&WorkspaceHelper::openNewTab)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (WorkspaceHelper::*)(const QList<QUrl> & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&WorkspaceHelper::requestSelectFiles)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (WorkspaceHelper::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&WorkspaceHelper::trashStateChanged)) {
                *result = 2;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject dfmplugin_workspace::WorkspaceHelper::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_dfmplugin_workspace__WorkspaceHelper.data,
    qt_meta_data_dfmplugin_workspace__WorkspaceHelper,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *dfmplugin_workspace::WorkspaceHelper::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dfmplugin_workspace::WorkspaceHelper::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_dfmplugin_workspace__WorkspaceHelper.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int dfmplugin_workspace::WorkspaceHelper::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void dfmplugin_workspace::WorkspaceHelper::openNewTab(quint64 _t1, const QUrl & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void dfmplugin_workspace::WorkspaceHelper::requestSelectFiles(const QList<QUrl> & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void dfmplugin_workspace::WorkspaceHelper::trashStateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
